------------------------------------------------------------------------------
-- MakeMeGetMyMain - Alarms you when something happens to your character
------------------------------------------------------------------------------
-- Data.lua - Export and Import Data
--
-- Author: Expelliarm5s / January 2023 / All Rights Reserved
--
-- Version 1.1.23
------------------------------------------------------------------------------
-- luacheck: ignore 212 globals DLAPI GetBindingKey SetBinding

local addonName, addon = ...
local Data = addon:NewModule("Data", "AceConsole-3.0")
local AceSerializer = LibStub("AceSerializer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale(addonName)
-- local private = {}
-------------------------------------------------------------------------------------------------------

------------------------------------------------------------------------------
-- Debug Stuff

function Data:DebugPrintf(...)
	if addon.isDebug then
		local status, res = pcall(format, ...)
		if status then
			addon:DebugLog("DTA~" .. res)
		end
	end
end

------------------------------------------------------------------------------
-- Login

function Data:Login()
	Data:DebugPrintf("Login()")
end

function Data:Export()
	Data:DebugPrintf("Export()")

	local data = {
		VERSION = addon.METADATA.VERSION,
		MMGMM_ENABLE = GetBindingKey("MMGMM_ENABLE") or "",
		MMGMM_DISABLE = GetBindingKey("MMGMM_DISABLE") or "",
		}

	for key, val in pairs(addon.db.global) do
		Data:DebugPrintf("key=%s, type(val)=%s, val=%s", tostring(key), type(val), tostring(val))
		data[key] = val
	end

	if data then
		addon:Printf(L["Export Options Data"])

		-- serialize data
		local dataSerz = AceSerializer:Serialize(data)

		if dataSerz then
			return nil, dataSerz
		else
			return "Cannot export options data!"
		end
	else
		return "Cannot find options data!"
	end
end

function Data:Import(dataSerz)
	Data:DebugPrintf("Import()")

	local result, data = AceSerializer:Deserialize(dataSerz)
	if not result then
		return "Invalid Options Data: " .. data
	end

	if data then

		if data.VERSION and data.VERSION == addon.METADATA.VERSION then
			for key, val in pairs(data) do
				Data:DebugPrintf("key=%s, type(val)=%s, val=%s", tostring(key), type(val), tostring(val))
				if key == "MMGMM_ENABLE" then
					SetBinding(val, "MMGMM_ENABLE")
				elseif key == "MMGMM_DISABLE" then
					SetBinding(val, "MMGMM_DISABLE")
				else
					addon.db.global[key] = val
				end
			end
			addon.db.global.enabled = addon.db.global.enabled or false
			addon.isEnabled = addon.db.global.enabled

			addon:DebugPrintf("Imported Options Data")
			addon:Printf("Imported Options Data")
			addon.GUI:SetStatusLine("Imported Options Data successfully!")
		else
			return format("Cannot import options data of version %s into version %s", tostring(data.VERSION), tostring(addon.METADATA.VERSION))
		end
	else
		return "Cannot find options data"
	end
end

-- EOF
